# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/markhorwear/basic/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Markhorwear\\Basic\\": "packages/markhorwear/basic/src",
            "Markhorwear\\Basic\\Seeders\\": "packages/markhorwear/basic/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Markhorwear\Basic\Providers\BasicServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Basic'  => Markhorwear\Basic\Facades\Basic::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Markhorwear\\Basic\\Seeders\\BasicTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Markhorwear\Basic\Providers\BasicServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Markhorwear\Basic\Providers\BasicServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Markhorwear\Basic\Providers\BasicServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/basic/{modulename}

**User**

    http://path-to-route-folder/user/basic/{modulename}

**Public**

    http://path-to-route-folder/basics


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/basic/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/basic/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/basic/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/basic/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/basic/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/basic/{modulename}/{slug}
    METHOD: GET